//+------------------------------------------------------------------+
//|                                                Fractals-MTF.mq4  |
//|                                         Alexander Kalinovski (c) |
//+------------------------------------------------------------------+
#property link      "Alexander Kalinovski (c)"

#property indicator_chart_window
#property indicator_buffers 8
#property indicator_color1 Red
#property indicator_color2 Blue
#property indicator_color3 Lime
#property indicator_color4 Sienna
#property indicator_color5 Red
#property indicator_color6 Blue
#property indicator_color7 Lime
#property indicator_color8 Sienna

extern int P1 = 90;  //  
extern int P2 = 120; //  
extern int P3 = 180; //  
extern int P4 = 240; //  
extern bool ShowZigZag = false; //     

double FractalsBuffer1[];
double FractalsBuffer2[];
double FractalsBuffer3[];
double FractalsBuffer4[];
double WaveBuffer1[];
double WaveBuffer2[];
double WaveBuffer3[];
double WaveBuffer4[];

#define UP 0
#define DN 1
 
void show_info()
{
   int start_x = 3;
   int delta_x = 35;
   
   ObjectCreate("P1", OBJ_LABEL, 0, 0, 0);
   ObjectSetText("P1", "M0" + P1, 8, "Verdana", Red);
   ObjectSet("P1", OBJPROP_XDISTANCE, start_x);  
   ObjectSet("P1", OBJPROP_YDISTANCE, 20);
   start_x = start_x + delta_x;

   ObjectCreate("P2", OBJ_LABEL, 0, 0, 0);
   ObjectSetText("P2", "M" + P2, 8, "Verdana", Blue);
   ObjectSet("P2", OBJPROP_XDISTANCE, start_x);  
   ObjectSet("P2", OBJPROP_YDISTANCE, 20);
   start_x = start_x + delta_x;
   
   ObjectCreate("P3", OBJ_LABEL, 0, 0, 0);
   ObjectSetText("P3", "M" + P3, 8, "Verdana", Lime);
   ObjectSet("P3", OBJPROP_XDISTANCE, start_x);  
   ObjectSet("P3", OBJPROP_YDISTANCE, 20);
   start_x = start_x + delta_x;
   
   ObjectCreate("P4", OBJ_LABEL, 0, 0, 0);
   ObjectSetText("P4", "M" + P4, 8, "Verdana", Sienna);
   ObjectSet("P4", OBJPROP_XDISTANCE, start_x);  
   ObjectSet("P4", OBJPROP_YDISTANCE, 20);
}

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   SetIndexStyle(0,DRAW_ARROW);
   SetIndexArrow(0,119);
   SetIndexBuffer(0,FractalsBuffer1);
   SetIndexEmptyValue(0,0.0);

   SetIndexStyle(1,DRAW_ARROW);
   SetIndexArrow(1,119);
   SetIndexBuffer(1,FractalsBuffer2);
   SetIndexEmptyValue(1,0.0);

   SetIndexStyle(2,DRAW_ARROW);
   SetIndexArrow(2,119);
   SetIndexBuffer(2,FractalsBuffer3);
   SetIndexEmptyValue(2,0.0);

   SetIndexStyle(3,DRAW_ARROW);
   SetIndexArrow(3,119);
   SetIndexBuffer(3,FractalsBuffer4);
   SetIndexEmptyValue(3,0.0);

   SetIndexStyle(4,DRAW_SECTION);
   SetIndexBuffer(4,WaveBuffer1);
   SetIndexEmptyValue(4,0.0);

   SetIndexStyle(5,DRAW_SECTION);
   SetIndexBuffer(5,WaveBuffer2);
   SetIndexEmptyValue(5,0.0);

   SetIndexStyle(6,DRAW_SECTION);
   SetIndexBuffer(6,WaveBuffer3);
   SetIndexEmptyValue(6,0.0);

   SetIndexStyle(7,DRAW_SECTION);
   SetIndexBuffer(7,WaveBuffer4);
   SetIndexEmptyValue(7,0.0);
   
   return(0);
}
  
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
   ObjectDelete("P1");
   ObjectDelete("P2");
   ObjectDelete("P3");   
   ObjectDelete("P4");   
   
   return(0);
}

//------------------------------------------------------------------  
bool Fractal (int f, int per, int shift)
{
   if (per < Period()) return(-1);
   
   per = per / Period() * 2 + MathCeil(per / Period() / 2);
   if (shift < per || shift > Bars - per) return(-1);

   for (int i=1; i <= per; i++)
     {
      if (f == UP)
      {
         if (High[shift + i] >  High[shift]) return(-1);
         if (High[shift - i] >= High[shift]) return(-1);     
      }
      
      if (f == DN)
      {
         if (Low[shift + i] <  Low[shift]) return(-1);
         if (Low[shift - i] <= Low[shift]) return(-1);
      }        
   }
   
   return(1);   
}  

//------------------------------------------------------------------
int start()
{  
   double P;
   int bars_count = Bars;
   int M90 = 90, M120 = 120, M180 = 180, M720 = 720;
   
   if (Period() == 720)        P = Point * 10;     
   if (Period() == 180)        P = Point * 6; 
   if (Period() == 120)        P = Point * 6;       
   if (Period() == 90)         P = Point * 5;    
   
   if (Period() == PERIOD_D1)  P = Point * 15;
   if (Period() == PERIOD_H4)  P = Point * 7; 
   if (Period() == PERIOD_H1)  P = Point * 4; 
   if (Period() == PERIOD_M30) P = Point * 3; 
   if (Period() == PERIOD_M15) P = Point * 2; 
   if (Period() == PERIOD_M5)  P = Point * 1; 
   if (Period() == PERIOD_M1)  P = Point * 0.5;
     
   for (int shift = bars_count; shift>0; shift--)
   {
       if (Fractal(UP, P1, shift) == 1) 
       {
          FractalsBuffer1[shift] = High[shift] + P;
          WaveBuffer1[shift]     = High[shift] + P;
       } 
       else if (Fractal(DN, P1, shift) == 1) 
       {
          FractalsBuffer1[shift] = Low[shift] - P;
          WaveBuffer1[shift]     = Low[shift] - P;       
       }
       else 
       {
          FractalsBuffer1[shift] = 0;
          WaveBuffer1[shift]     = 0;
       }                     
       
       if (Fractal(UP, P2, shift) == 1) 
       {
          FractalsBuffer2[shift] = High[shift] + P;
          WaveBuffer2[shift]     = High[shift] + P;
       } 
       else if (Fractal(DN, P2, shift) == 1) 
       {
          FractalsBuffer2[shift] = Low[shift] - P;
          WaveBuffer2[shift]     = Low[shift] - P;       
       }
       else 
       {
          FractalsBuffer2[shift] = 0;
          WaveBuffer2[shift]     = 0;
       }             
       
       if (Fractal(UP, P3, shift) == 1) 
       {
          FractalsBuffer3[shift] = High[shift] + P;
          WaveBuffer3[shift]     = High[shift] + P;
       } 
       else if (Fractal(DN, P3, shift) == 1) 
       {
          FractalsBuffer3[shift] = Low[shift] - P;
          WaveBuffer3[shift]     = Low[shift] - P;       
       }
       else 
       {
          FractalsBuffer3[shift] = 0;
          WaveBuffer3[shift]     = 0;
       }
       
       if (Fractal(UP, P4, shift) == 1) 
       {
          FractalsBuffer4[shift] = High[shift] + P;
          WaveBuffer4[shift]     = High[shift] + P;
       } 
       else if (Fractal(DN, P4, shift) == 1) 
       {
          FractalsBuffer4[shift] = Low[shift] - P;
          WaveBuffer4[shift]     = Low[shift] - P;       
       }
       else 
       {
          FractalsBuffer4[shift] = 0;
          WaveBuffer4[shift]     = 0;
       }
       
       if (!ShowZigZag)
       {
          WaveBuffer1[shift] = 0;
          WaveBuffer2[shift] = 0;
          WaveBuffer3[shift] = 0;
          WaveBuffer4[shift] = 0;
       }
   }
   
   show_info();

   return(0);
}